*********
Reference
*********

The API directly from the docstrings in the code_.

.. _code: http://github.com/mattions/neuronvisio

.. toctree::
    :maxdepth: 2
    
    manager
    visio
    controls
    